Django RPC documentation — Django RPC 0.1 documentation

### Navigation

- index
- modules |
- next |
- Django RPC 0.1 documentation »

# Django RPC documentation

Django RPC for jQuery. Allows execute some server-side class methods with Javascript in your browser.

Also you can submit forms with jQuery Form Plugin.

It also supports call batching. Django RPC batches together calls which are received within a configurable time frame and sends them in a single request.

You can easy move you current views to RPC methods and use Django RPC instead of mess of AJAX requests.

Inspired by Ext.Direct from ExtJs 3.

## Support

You can ask question or report bug on project Github repo.

## Requirements

Django RPC requires the following:

- Python (2.6.5+, 2.7)
- Django (1.3, 1.4, 1.5)

## Contents

- Installation
- Example
- Tutorial
  - Part 1: The Basics
  - Part 2: Handling forms
  - Part 3: Javascript API
  - Part 4: Useful tricks
- API Guide
  - Base classes
  - Responses
  - Decorators
  - Exceptions
  - Utils

### Navigation

- index
- modules |
- next |
- Django RPC 0.1 documentation »